﻿using System;
using System.Collections.Generic;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Data;
using System.Text;
using System.IO;

namespace ExtAspNet.Examples.data
{
    public partial class grid_autopostback_run : PageBase
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                LoadData();
            }
        }

        #region LoadData
        private void LoadData()
        {
            DataTable table = IniGrid();

            Grid1.DataSource = table;
            Grid1.DataBind();
        }

        private static DataTable IniGrid()
        {
            DataTable table = new DataTable();
            DataColumn column1 = new DataColumn("Id", typeof(int));
            DataColumn column2 = new DataColumn("MyText", typeof(String));
            DataColumn column3 = new DataColumn("MyValue", typeof(String));
            DataColumn column4 = new DataColumn("Year", typeof(String));
            DataColumn column5 = new DataColumn("MyCheckBox", typeof(bool));
            table.Columns.Add(column1);
            table.Columns.Add(column2);
            table.Columns.Add(column3);
            table.Columns.Add(column4);
            table.Columns.Add(column5);

            DataRow row = table.NewRow();
            row["Id"] = 101;
            row["MyText"] = "item1";
            row["MyValue"] = "1";
            row["Year"] = "2008";
            row["MyCheckBox"] = true;
            table.Rows.Add(row);

            row = table.NewRow();
            row["Id"] = 102;
            row["MyText"] = "item2";
            row["MyValue"] = "2";
            row["Year"] = "2007";
            row["MyCheckBox"] = true;
            table.Rows.Add(row);

            row = table.NewRow();
            row["Id"] = 103;
            row["MyText"] = "item3, I am a great programmer.";
            row["MyValue"] = "3";
            row["Year"] = "2006";
            row["MyCheckBox"] = false;
            table.Rows.Add(row);

            row = table.NewRow();
            row["Id"] = 104;
            row["MyText"] = "item4。";
            row["MyValue"] = "4";
            row["Year"] = "2005";
            row["MyCheckBox"] = false;
            table.Rows.Add(row);

            row = table.NewRow();
            row["Id"] = 105;
            row["MyText"] = "item5";
            row["MyValue"] = "5";
            row["Year"] = "2004";
            row["MyCheckBox"] = true;
            table.Rows.Add(row);

            return table;
        }

        #endregion

        #region MyClass

        public class MyClass
        {
            private int _myValue;

            public int MyValue
            {
                get { return _myValue; }
                set { _myValue = value; }
            }
            private string _myText;

            public string MyText
            {
                get { return _myText; }
                set { _myText = value; }
            }

            private string _year;

            public string Year
            {
                get { return _year; }
                set { _year = value; }
            }

            private int _id;

            public int Id
            {
                get { return _id; }
                set { _id = value; }
            }

            private bool _myCheckBox;

            public bool MyCheckBox
            {
                get { return _myCheckBox; }
                set { _myCheckBox = value; }
            }

            public MyClass(int id, int myValue, string myText, string year, bool myCheckBox)
            {
                _id = id;
                _myValue = myValue;
                _myText = myText;
                _year = year;
                _myCheckBox = myCheckBox;
            }
        }

        #endregion

        #region GetMyValue

        protected string GetMyValue(object value)
        {
            return (Convert.ToInt32(value) * 100).ToString();
        }

        #endregion

        #region Event Grid

        protected void Grid1_PreRowDataBound(object sender, ExtAspNet.GridPreRowEventArgs e)
        {
            ExtAspNet.LinkButtonField lbfAction1 = Grid1.Columns.FindColumnById("lbfAction1") as ExtAspNet.LinkButtonField;
            ExtAspNet.LinkButtonField lbfAction2 = Grid1.Columns.FindColumnById("lbfAction2") as ExtAspNet.LinkButtonField;

            if (e.RowIndex % 2 == 0)
            {
                lbfAction1.Enabled = false;
                lbfAction2.Enabled = false;
            }
            else
            {
                lbfAction1.Enabled = true;
                lbfAction2.Enabled = true;
            }
        }

        protected void Grid1_RowDataBound(object sender, ExtAspNet.GridRowEventArgs e)
        {
            // DataItem是行的数据源，
            // 如果数据源是DataTable/DataView/DataSet，则e.DataItem是DataRow
            // 如果数据源是List<MyClass>，则e.DataItem是MyClass

            // e.Values 是实际赋予此行每列的值，可以修改

            ExtAspNet.WindowField windowField1 = Grid1.Columns.FindColumnById("myWindowField") as ExtAspNet.WindowField;

            DataRow row = e.DataItem as DataRow;
            if (row != null)
            {
                e.Values[1] = String.Format("RowDataBound - {0}", row["MyValue"]);
            }
        }

        protected void Grid1_RowCommand(object sender, ExtAspNet.GridCommandEventArgs e)
        {
            if (e.CommandName == "Action1" || e.CommandName == "Action2")
            {
                Alert.Show(String.Format("You click line: {0}, CommandName: {1}", e.RowIndex + 1, e.CommandName));
            }
        }

        protected void Grid1_RowClick(object sender, ExtAspNet.GridRowClickEventArgs e)
        {
            Alert.Show(String.Format("You click line: {0}", e.RowIndex + 1));
        }

        #region

        #endregion Event Button

        /// <summary>
        /// 回发How many lines were selected
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Button1_Click(object sender, EventArgs e)
        {
            StringBuilder sb = new StringBuilder();
            if (Grid1.SelectedRowIndexArray != null && Grid1.SelectedRowIndexArray.Length > 0)
            {
                sb.Append("<span style=\"font-weight:bold;\">Following lines were selected: </span>");
                for (int i = 0, count = Grid1.SelectedRowIndexArray.Length; i < count; i++)
                {
                    int rowIndex = Grid1.SelectedRowIndexArray[i];
                    sb.AppendFormat("<br/><span style=\"font-weight:bold;\">Line {0}: </span>", rowIndex + 1);

                    sb.Append("&nbsp;&nbsp;&nbsp;&nbsp;");
                    foreach (object key in Grid1.DataKeys[rowIndex])
                    {
                        sb.Append(key);
                        sb.Append("&nbsp;&nbsp;&nbsp;&nbsp;");
                    }
                }
            }
            else
            {
                sb.Append("<span style=\"font-weight:bold;\">No line was selected.</span>");
            }

            labResult.Text = sb.ToString();
        }

        /// <summary>
        /// 选中第5、4、2行
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Button2_Click(object sender, EventArgs e)
        {
            Grid1.SelectedRowIndexArray = new int[] { 4, 3, 1 };
        }


        protected void Button3_Click(object sender, EventArgs e)
        {
            if (ViewState["ShowColumns2"] == null || Convert.ToBoolean(ViewState["ShowColumns2"]))
            {
                Grid1.Columns.FindColumnById("lbfAction1").Visible = false;
                Grid1.Columns.FindColumnById("lbfAction2").Visible = false;

                //BindGrid();

                ViewState["ShowColumns2"] = false;
            }
            else
            {
                Grid1.Columns.FindColumnById("lbfAction1").Visible = true;
                Grid1.Columns.FindColumnById("lbfAction2").Visible = true;

                //BindGrid(); 

                ViewState["ShowColumns2"] = true;
            }
        }

        #endregion

    }
}
