﻿using System;
using System.Collections.Generic;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Data;
using System.Text;
using System.IO;
using AspNet = System.Web.UI.WebControls;

namespace ExtAspNet.Examples.data
{
    /// <summary>
    /// 可以参考文章：http://www.highoncoding.com/Articles/197_Extensive%20Study%20of%20GridView%20Export%20to%20Excel.aspx
    /// 或者中文译本：http://www.cnblogs.com/stswordman/archive/2006/08/24/485641.html
    /// </summary>
    public partial class grid_excel_run : PageBase
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                BindGrid();
            }
        }

        #region BindGrid
        private void BindGrid()
        {
            DataTable table = IniGrid();

            Grid1.DataSource = table;
            Grid1.DataBind();

            GridView1.DataSource = table;
            GridView1.DataBind();

        }

        private static DataTable IniGrid()
        {
            DataTable table = new DataTable();
            DataColumn column1 = new DataColumn("Id", typeof(int));
            DataColumn column2 = new DataColumn("MyText", typeof(String));
            DataColumn column3 = new DataColumn("MyValue", typeof(String));
            DataColumn column4 = new DataColumn("Year", typeof(String));
            DataColumn column5 = new DataColumn("MyCheckBox", typeof(bool));
            table.Columns.Add(column1);
            table.Columns.Add(column2);
            table.Columns.Add(column3);
            table.Columns.Add(column4);
            table.Columns.Add(column5);

            DataRow row = table.NewRow();
            row["Id"] = 101;
            row["MyText"] = "item1";
            row["MyValue"] = "1";
            row["Year"] = "2008";
            row["MyCheckBox"] = true;
            table.Rows.Add(row);

            row = table.NewRow();
            row["Id"] = 102;
            row["MyText"] = "item2";
            row["MyValue"] = "2";
            row["Year"] = "2007";
            row["MyCheckBox"] = true;
            table.Rows.Add(row);

            row = table.NewRow();
            row["Id"] = 103;
            row["MyText"] = "item3, I am a great programmer.";
            row["MyValue"] = "3";
            row["Year"] = "2006";
            row["MyCheckBox"] = false;
            table.Rows.Add(row);

            row = table.NewRow();
            row["Id"] = 104;
            row["MyText"] = "item4。";
            row["MyValue"] = "4";
            row["Year"] = "2005";
            row["MyCheckBox"] = false;
            table.Rows.Add(row);

            row = table.NewRow();
            row["Id"] = 105;
            row["MyText"] = "item5";
            row["MyValue"] = "5";
            row["Year"] = "2004";
            row["MyCheckBox"] = true;
            table.Rows.Add(row);

            return table;
        }

        #endregion



        #region Grid1




        protected void Grid1_RowDataBound(object sender, ExtAspNet.GridRowEventArgs e)
        {
            ExtAspNet.WindowField windowField1 = Grid1.Columns.FindColumnById("myWindowField") as ExtAspNet.WindowField;

            DataRow row = e.DataItem as DataRow;
            if (row != null)
            {
                e.Values[1] = String.Format("RowDataBound - {0}", row["MyValue"]);
            }
        }


        #endregion


        protected string GetMyValue(object value)
        {
            return (Convert.ToInt32(value) * 100).ToString();
        }



        protected void Button1_Click(object sender, EventArgs e)
        {
            Response.ClearContent();
            Response.AddHeader("content-disposition", "attachment; filename=MyExcelFile.xls");
            Response.ContentType = "application/excel";
            Response.Write(GetGridTableHtml(Grid1));
            Response.End();
        }

        private string GetGridTableHtml(Grid grid)
        {
            StringBuilder sb = new StringBuilder();

            sb.Append("<table cellspacing=\"0\" rules=\"all\" border=\"1\" style=\"border-collapse:collapse;\">");

            sb.Append("<tr>");
            foreach (GridColumn column in grid.Columns)
            {
                sb.AppendFormat("<td>{0}</td>", column.HeaderText);
            }
            sb.Append("</tr>");


            foreach (GridRow row in grid.Rows)
            {
                sb.Append("<tr>");
                foreach (object value in row.Values)
                {
                    string html = value.ToString();
                    // 处理CheckBox
                    if (html.Contains("box-grid-static-checkbox"))
                    {
                        if (html.Contains("box-grid-static-checkbox-uncheck"))
                        {
                            html = "×";
                        }
                        else
                        {
                            html = "√";
                        }
                    }

                    // 处理图片
                    if (html.Contains("<img"))
                    {
                        html = html.Replace("src=\"/extaspnet/", "src=\"http://localhost/extaspnet/");
                    }

                    sb.AppendFormat("<td>{0}</td>", html);
                }
                sb.Append("</tr>");
            }

            sb.Append("</table>");

            return sb.ToString();
        }


        protected void Button2_Click(object sender, EventArgs e)
        {
            ResolveGridView(GridView1);

            Response.ClearContent();
            Response.AddHeader("content-disposition", "attachment; filename=MyExcelFile.xls");
            Response.ContentType = "application/excel";
            StringWriter sw = new StringWriter();
            HtmlTextWriter htw = new HtmlTextWriter(sw);
            GridView1.RenderControl(htw);
            Response.Write(sw.ToString());
            Response.End();
        }

        public override void VerifyRenderingInServerForm(Control control)
        {

        }

        private void ResolveGridView(Control ctrl)
        {
            for (int i = 0; i < ctrl.Controls.Count; i++)
            {
                // 图片的完整URL
                if (ctrl.Controls[i].GetType() == typeof(AspNet.Image))
                {
                    AspNet.Image img = ctrl.Controls[i] as AspNet.Image;
                    img.ImageUrl = "http://localhost" + Page.ResolveUrl(img.ImageUrl);
                }

                // 将CheckBox控件转化为静态文本
                if (ctrl.Controls[i].GetType() == typeof(AspNet.CheckBox))
                {
                    Literal lit = new Literal();
                    lit.Text = (ctrl.Controls[i] as AspNet.CheckBox).Checked ? "√" : "×";
                    ctrl.Controls.RemoveAt(i);
                    ctrl.Controls.AddAt(i, lit);
                }

                if (ctrl.Controls[i].HasControls())
                {
                    ResolveGridView(ctrl.Controls[i]);
                }

            }

        }
    }
}
